@@ -41,13 +41,8 @@ pub mod arrayvec;
 
 pub mod errors;
 
-pub mod defs;
-
-#[doc(inline)]
-pub use defs::SpareMemoryPolicy;
-
-#[doc(inline)]
-pub use defs::LengthType;
+pub mod len;
+pub mod mem;
 
 pub(crate) mod sealed;
 
